<template>
  <view-grid ref="grid" :columns="columns" :detail="detail" :editFormFields="editFormFields"
    :editFormOptions="editFormOptions" :searchFormFields="searchFormFields" :searchFormOptions="searchFormOptions"
    :table="table" :extend="extend">
  </view-grid>
</template>
<script>
import extend from "@/extension/stock/stockInfoDetail.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "库存信息明细",
      name: "stockInfoDetail",
      url: "/StockInfoDetail/",
      sortName: "id",
    });
    const editFormFields = ref({
      deviceCode: "",
      deviceName: "",
      deviceType: "",
      deviceStatus: "",
      deviceIp: "",
      devicePort: "",
      devicePlcType: "",
      deviceRemark: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "物料编号",
          required: true,
          field: "materielCode",
          type: "string",
        },
        {
          title: "单据编号",
          required: true,
          field: "materielName",
          type: "string",
        },
        {
          title: "批次号",
          required: true,
          field: "orderNo",
          type: "string",
        },
        {
          title: "包号",
          required: true,
          field: "serialNumber",
          type: "string",
        },
      ],
      
    ]);
    const searchFormFields = ref({
      materielCode: "",
      materielName: "",
      orderNo: "",
    });
    const searchFormOptions = ref([
      [
        { title: "物料编号", field: "materielCode",type:"like"},
        { title: "物料名称", field: "materielName",type:"like" },
        { title: "物料详情", field: "orderNo" ,type:"like"},
        
        
      ],
      [
      { title: "物料批次", field: "batchNo",type:"like" },
        { title: "物料批次详情", field: "batchNoName",type:"like" },
        { title: "重量", field: "stockQuantity",type:"like" },
      ],
      [
      {
          title: "库存明细状态",
          field: "stockQuantity",
          type:"like"
        },
        {
        field: "stockId",
        title: "库存信息主键",
        type: "string",
        width: 90,
        align: "left",
      },
      ]
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "stockId",
        title: "库存信息主键",
        type: "string",
        width: 90,
        align: "left",
        sort:true,
      },
      {
        field: "materielCode",
        title: "物料编号",
        type: "string",
        width: 150,
        align: "left",
        sort:true,
      },
      {
        field: "materielName",
        title: "物料名称",
        type: "string",
        width: 150,
        align: "left",
        sort:true,
      },
      {
        field: "orderNo",
        title: "物料详情",
        type: "decimal",
        width: 90,
        align: "left",
        sort:true,
      },
      {
        field: "batchNo",
        title: "物料批次",
        type: "string",
        width: 120,
        align: "left",
        sort:true,
      },
      {
        field: "serialNumber",
        title: "包号",
        type: "string",
        width: 50,
        align: "left",
        sort:true,
        },
      {
        field: "batchNoName",
        title: "物料批次详情",
        type: "int",
        width: 120,
        align: "left",
        sort:true,
      },
      {
        field: "stockQuantity",
        title: "重量",
        type: "string",
        width: 80,
        align: "left",
        sort:true,
      },
      {
        field: "status",
        title: "库存明细状态",
        type: "string",
        width: 120,
        align: "left",
        sort:true,
        bind: { key: "stockStatusEmun", data: [] },
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
        sort:true,
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
        sort:true,
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>